#!/usr/bin/env python3
import json
import pathlib
import matplotlib.pyplot as plt
from collections import defaultdict
# plt.plot(["feb", "mar", "apr", "may"], [1, 4, 9, 16])
# plt.ylabel('some numbers')
# plt.show()

def read_data(database_file):
    if database_file.is_file():
        with open(database_file, "r") as fp:
            data = json.load(fp)
    return data
#
# def write_data(database_file, data):
    # with open(database_file, "w") as fp:
        # json.dump(data, fp, indent=2)
#

database_file = pathlib.Path("book.json")
data = read_data(database_file)
print(f"Read {len(data)} records")
#
hist = defaultdict(int)
for book in data:
    if book["date"]:
        year = book["date"].split("/")[0]
        hist[year] += 1
#
# print(hist)
# for key in sorted(hist):
    # print

years = [key for key in sorted(hist)]
values = [hist[key] for key in sorted(hist)]
# print(years)
# print(values)
plt.plot(years, values)
plt.ylabel('number read')
plt.show()
#
# write_data(database_file, data)

# item = {}
# item["title"] = "t"
# item["author"] = "a"
# item["series"] = "s"
# item["date"] = "d"
# item["audiobook"] = "b"
# print(item)
# print(list(item.values()))



#!/usr/bin/env python3
import argparse
import json
import sys

from PyQt5.QtSql import QSqlDatabase, QSqlQuery


def get_command_line_args():
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-i", "--infile", default="book.json", help="json file to convert"
    )
    parser.add_argument(
        "-o", "--outfile", default="test.sqlite", help="sqlite output file"
    )
    return parser.parse_args()


def read_data(database_file):
    with open(database_file, "r") as fp:
        return json.load(fp)


def _createBooksTable():
    createTableQuery = QSqlQuery()
    return createTableQuery.exec(
        """
        CREATE TABLE IF NOT EXISTS books (
            id INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE NOT NULL,
            title VARCHAR(80) NOT NULL,
            author VARCHAR(80) NOT NULL,
            series VARCHAR(80),
            date TIMESTAMP,
            audio BOOLEAN
        )
        """
    )


def createConnection(databaseName):
    connection = QSqlDatabase.addDatabase("QSQLITE")
    connection.setDatabaseName(str(databaseName))
    if not connection.open():
        print("NO CONNECTION")
        sys.exit(1)
    _createBooksTable()
    return connection


if __name__ == "__main__":
    args = get_command_line_args()
    db = createConnection(args.outfile)
    query = QSqlQuery()
    query.prepare(
        "INSERT into books (title, author, series, date, audio) VALUES (:title, :author, :series, :date, :audio)"
    )
    data = read_data(args.infile)
    for item in data:
        print(f"adding {item}")
        query.bindValue(":title", item["title"])
        query.bindValue(":author", item["author"])
        query.bindValue(":series", item["series"])
        query.bindValue(":date", item["date"])
        # JHA TODO at some point I should figure out the boolean goofiness
        if item["audiobook"]:
            query.bindValue(":audio", 0)
        else:
            query.bindValue(":audio", 2)

        if not query.exec_():
            print("failed query")
            sys.exit(1)
    db.commit()



""" Task definitions for invoke command line utility for building, testing and
    releasing markplates. """
from invoke import run
from invoke import task
import setuptools
import sys

VERSION = "1.0.0"


@task
def test(c):
    """Run unit tests with coverage report."""
    pass


@task
def tox(c):
    """Run tox to test all supported Python versions."""
    # run("tox")
    pass


@task
def format(c):
    """Run black over all source to reformat."""
    files = ["bookdog", "tasks.py", "setup.py"]
    for name in files:
        run(f"black {name}")


@task
def clean(c, bytecode=False, test=False, extra=""):
    """Remove any built objects.  -b removes bytecode, -t testfiles -e extra"""
    patterns = ["build/", "dist/", "bookdog.egg-info/"]
    if bytecode:
        patterns.extend(("__pycache__/", "bookdog/__pycache__/", "tests/__pycache__/"))
    if test:
        patterns.extend((".coverage", ".pytest_cache/", ".tox/"))
    if extra:
        patterns.append(extra)
    for pattern in patterns:
        c.run(f"rm -rf {pattern}")


def status(s):
    """Prints things in bold."""
    print("\033[1m{0}\033[0m".format(s))


@task
def patch(c):
    """Update version for patch release."""
    status(f"Updating version from {VERSION}…")
    run("bumpversion patch --tag --commit")


@task
def version(c):
    """Update version for minor release."""
    status(f"Updating version from {VERSION}…")
    run("bumpversion minor --tag --commit")


@task
def distclean(c):
    """Cleans up everything."""
    status("Cleaning project…")
    clean(c, True, True)


@task
def build(c):
    """Builds source and wheel distributions"""
    status("Building Source and Wheel (universal) distribution…")
    run("{0} setup.py sdist bdist_wheel --universal".format(sys.executable))


@task
def check_dist(c):
    """Uses twine to check distribution."""
    status("Checking dist")
    run("twine check dist/*")


@task(distclean, build, check_dist)
def release(c):
    """Creates distribution and pushes to PyPi."""
    status("Uploading the package to PyPI via Twine…")
    run("twine upload dist/*")

    status("Pushing git tags…")
    run("git push --tags")


@task(distclean, build, check_dist)
def test_release(c):
    """ Push to test PyPi.
        Use this command to test the download:
        pip install --index-url https://test.pypi.org/simple/ \
                --extra-index-url https://pypi.org/simple your-package
    """
    status("Uploading the package to TEST PyPI via Twine…")
    run("twine upload --repository-url https://test.pypi.org/legacy/ dist/*")
